@@ -6,6 +6,7 @@ use warnings;
 
 # Modules.
 use Class::Utils qw(set_params);
+use Error::Pure qw(err);
 use English;
 use File::Basename qw(fileparse);
 use File::Spec::Functions qw(catfile);
@@ -13,7 +14,7 @@ use Image::Random;
 use Video::Delay::Const;
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -42,6 +43,18 @@ sub new {
 	# Process params.
 	set_params($self, @params);
 
+	# Check fps value.
+	if (! defined $self->{'fps'} || $self->{'fps'} !~ m/^\d+$/ms) {
+		err "Parameter 'fps' must be numeric value.";
+	}
+
+	# Check for duration value.
+	if (! defined $self->{'duration'}
+		|| $self->{'duration'} !~ m/^\d+$/ms) {
+
+		err "Parameter 'duration' must be numeric value.";
+	}
+
 	# Own image generator.
 	if (! defined $self->{'image_generator'}) {
 		$self->{'image_generator'} = Image::Random->new(
@@ -174,6 +187,8 @@ Video::Pattern - Video class for frame generation.
 =head1 ERRORS
 
  new():
+         Parameter 'duration' must be numeric value.
+         Parameter 'fps' must be numeric value.
          From Class::Utils::set_params():
                  Unknown parameter '%s'.
 
@@ -243,9 +258,21 @@ On Windows L<File::Copy> or L<Win32::Symlink>.
 
 =head1 SEE ALSO
 
-L<Video::Delay::Array>,
-L<Video::Delay::Const>,
-L<Video::Delay::Func>.
+=over
+
+=item L<Video::Delay::Array>
+
+Video::Delay class for predefined list of delays.
+
+=item L<Video::Delay::Const>
+
+Video::Delay class for constant delay.
+
+=item L<Video::Delay::Func>
+
+Video::Delay class for delays defined by math function.
+
+=back
 
 =head1 REPOSITORY
 
@@ -259,10 +286,11 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD 2-Clause License
+ © 2012-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
